#
# spec file for package gthumb
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gthumb
Version:        3.12.5
Release:        1.1
# FIXME: Add libchamplain BuildRequires once the map feature is considered stable.
Summary:        An Image Viewer and Browser for GNOME
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Viewers
URL:            https://wiki.gnome.org/Apps/gthumb
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  AppStream
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  gnome-doc-utils-devel
BuildRequires:  intltool >= 0.50.1
BuildRequires:  itstool
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(appstream) >= 0.14.6
BuildRequires:  pkgconfig(champlain-0.12) >= 0.12.0
BuildRequires:  pkgconfig(champlain-gtk-0.12) >= 0.12.0
BuildRequires:  pkgconfig(clutter-1.0) >= 1.12.0
BuildRequires:  pkgconfig(clutter-gtk-1.0) >= 1.0.0
BuildRequires:  pkgconfig(colord) >= 1.3
BuildRequires:  pkgconfig(exiv2) >= 0.21
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.36.0
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.0.0
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.16
BuildRequires:  pkgconfig(json-glib-1.0) >= 0.15.0
BuildRequires:  pkgconfig(lcms2) >= 2.6
BuildRequires:  pkgconfig(libbrasero-burn3) >= 3.2.0
BuildRequires:  pkgconfig(libheif) >= 1.11
BuildRequires:  pkgconfig(libjxl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libraw) >= 0.14
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.34.0
BuildRequires:  pkgconfig(libsecret-1) >= 0.11
BuildRequires:  pkgconfig(libsoup-2.4) >= 2.42
BuildRequires:  pkgconfig(libwebp) >= 0.2.0
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} < 1315
BuildRequires:  pkgconfig(webkit2gtk-3.0)
%else
BuildRequires:  pkgconfig(webkit2gtk-4.0)
%endif

%description
gThumb lets you browse your hard disk, showing you thumbnails of image
files. It also lets you view single files (including GIF animations),
add comments to images, organize images in catalogs, print images, view
slide shows, set your desktop background, and more.

%package devel
Summary:        An Image Viewer and Browser for GNOME - Development Files
Group:          Development/Libraries/GNOME
Requires:       %{name} = %{version}

%description devel
gThumb lets you browse your hard disk, showing you thumbnails of image
files. It also lets you view single files (including GIF animations),
add comments to images, organize images in catalogs, print images, view
slide shows, set your desktop background, and more.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-Dlibchamplain=true \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_prefix}

%check
%meson_test

%files
%license COPYING
%doc AUTHORS NEWS README.md
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/gthumb
%{_datadir}/gthumb/
%{_libdir}/gthumb/
%{_libexecdir}/gthumb/
%if 0%{?sle_version} > 150300 || 0%{?suse_version} > 1590
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/org.gnome.gThumb.appdata.xml
%endif
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/org.gnome.gThumb*
%{_datadir}/glib-2.0/schemas/org.gnome.gthumb.*.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.gthumb.enums.xml
%{_datadir}/glib-2.0/schemas/org.gnome.gthumb.gschema.xml
%{_mandir}/man1/gthumb.1%{?ext_man}

%files devel
%doc MAINTAINERS
%{_includedir}/%{name}/
%{_datadir}/aclocal/gthumb.m4
%{_libdir}/pkgconfig/*.pc

%files lang -f %{name}.lang

%changelog
* Mon Feb 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.12.5:
  + Add to catalog: show the next image only when in viewer mode.
* Wed Jan 17 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.12.4+3:
  + jxl: added support for version 0.9.0.
  + Commenting a picture deletes its Color Profile tag.
- Convert to source service for easier updating.
* Tue Oct 10 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.12.4:
  + Bugfixes:
  - Crop: lost the custom sizing for Aspect Ratio "Other".
  - Do not use symbols not available in glib 2.54.0.
  - Build failed.
  + Updated translations.
* Tue Aug 29 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 3.12.3:
  + Features:
  - Added ability to open the image stored in the clipboard with
    Ctrl+Shift+V (!243)
  - Added ability to sort folders by modification time from the
    context menu
  - Media viewer: added ability to copy the current frame to the
    clipboard with Ctrl+Shift+C
  - Tiff and TGA files: added support for transparency
  - Image viewer: added support for the zoom gesture (!50)
  - Drag&Drop: allow to copy pressing Shift (matthewmelvin)
  - Image tools: allow to use Return to apply the changes
  - Rename series: added special code to add the filename without
    extension
  - Rename series: added ability to specify the current time
  - Crop: added 1.91:1 to the list of predefined ratios
  - Added an internal video thumbnailer
  - Try to load the parent folder if the startup folder doesn't
    exist
  - Make keypad keys equivalent to the non-keypad counterpart
    (!238) (!239)
  - Improved usability when editing metadata in browser mode
    (!267)
  - Zoom slider: set the zoom range from 5%% to 1000%%
  + Bugfixes:
  - Allow to compile without clutter-gtk (Matt Turner) (!222)
  - Fixed build with exiv2 version 0.28 (Alex and Antonio Rojas)
  - Fixed build with libraw 0.21
  - Reduced memory usage by keeping in memory only the visible
    thumbnails
  - Rename series: fixed date format not applied correctly;
    preview does not show example values
  - Desktop background: fixed when using the dark color scheme
  - Fixed memory leaks
  - Fixed directory not loaded when cancelling the thumbnailer
  - Help: Added gThumb icon (Sabri Ünal)
  - TGA files displayed pixelated
  - Status bar reappears after exiting from full screen
- Drop c97a8aaa.patch: fixed on upstream.
- Drop da0d3f22.patch: fixed on upstream.
- Drop 3376550a.patch: fixed on upstream.
* Fri Jul 14 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Add pkgconfig(libjxl) BuildRequires: enable JPEG XL image
  support.
- Add c97a8aaa.patch: desktop background: fixed when using the dark
  color scheme
* Mon Jul  3 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add 3376550a.patch: exiv2: added support for version 0.28.
- Refresh da0d3f22.patch from upstream git.
* Mon Jan 16 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add da0d3f22.patch: Fix build with libraw 0.21.
* Wed Apr 27 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add relevant version limit to pkgconfig(appstream) BuildRequires.
* Wed Apr  6 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 3.12.2 (boo#1209655 boo#1209656):
  + Fixed possible crash when changing directory during
    thumbnails creation.
  + Added support for larger thumbnail sizes: 512, 768 and
    1024 pixels.
* Tue Mar 22 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.12.1:
  + PNG loader ignores gAMA.
  + Transparent webp images are rendered incorrectly.
  + Crash when dropping files on an empty folder/catalog.
  + Fixed location loading after mounting volume.
  + JPEG image dimensions not displayed for files inside the
    trash.
  + Infinite Loop when viewing more than 50 thumbnails.
  + X11 window title is not set.
  + Copy release notes on build from NEWS to metainfo file.
  + Fixed build if appstream >= 0.14.6 is not available.
  + Fix incorrect usage of shared_module in extensions.
  + cli: mention that user can open files and/or directories.
  + Updated translations.
- Drop daef485dffd67319c114cf1bda453bf6157e11ff.patch: Fixed
  upstream.
- Add pkgconfig(appstream) and AppStream BuildRequires: Needed to
  build and install appdata now.
* Thu Feb 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add daef485dffd67319c114cf1bda453bf6157e11ff.patch: Remove
  duplicate lang entry.
* Fri Nov  5 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Stop passing tracing=false and documentation=true to meson, no
  longer needed.
* Mon Sep 20 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add pkgconfig(libheif) BuildRequires: Add support for heif/avif.
- Add pkgconfig(champlain-0.12) and pkgconfig(champlain-gtk-0.12)
  BuildRequires and pass libchamplain=true to meson: Use
  libchamplain to show the position the image refers to.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Mon Sep 20 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to version 3.12.0:
  + New features and user visible changes:
  - Added ability to load AVIF/HEIF images using libheif.
  - Added ability to save images as AVIF.
  - Add JPEG XL (*.jxl) read support.
  - File manager: added file actions to the viewer
    context menu.
  - Extensions: removed facebook and picasaweb uploaders.
  - Image viewer: use a proportional zoom increment.
  - Read color profiles from png files as well.
  - Media viewer: use accurate seeking when clicking on
    the progress bar.
  - Media viewer: show the pointed time when hovering over
    the progress bar.
  - Preferences: added option to show/hide the statusbar.
  - Rename files: added a button to revert to the last
    used template.
  - Added configurable shortcuts for Save and Save As.
  - Media viewer: added keyboard shortcuts.
  - File list: always allow to use Control-A to select
    all files.
  - Allow to set shortcuts to activate filters.
  - Added a template editor to edit text values with
    special codes: script commands, rename templates,
    print header and footer, etc.
  - Faster navigation when a directory contains
    thousands of images.
  - File list: start more thumbnailers in parallel.
  - Allow to mount unmounted volumes.
  - Color picker: added other formats: rgb in %% and hsl.
  - Allow to keep browsing while executing long-running
    external tools.
  - Status bar: added button to show the progress dialog.
  - File properties: do not reset the selection after showing
    another image.
  - Histogram: show the properties in a single column
    to save horizontal space.
  + Bugs fixed:
  - Install the gThumb import desktop file.
  - Fix memory leak when loading webp, jxl, avif images.
  - Check if image is null before using it.
  - Added a Flatpak manifest.
  - Contact sheet: fixed themes list always empty.
  - Raw: Make compatible with LibRaw 0.21
  - Folder context menu: do not allow to move if cannot delete.
  - Folder context menu: do not allow to copy not mounted
    volumes.
  - Terminal: enable only for local folders.
  - Lots of others small fixes.
* Mon Aug 23 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.10.4:
  + Install the gThumb import desktop file.
  + Contact sheet: fixed themes list always empty.
  + Thumbnailer: try with the system thumbnailer if the image is
    null
  + File chooser: correctly get the filename extension.
  + Updated translations.
* Tue Apr 13 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to version 3.10.3:
  + Fix possible build error.
  + Updated translations.
* Sun Jan 31 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.10.2:
  + Continuously reloads image when it is only image in folder.
  + exiv2: remove the charset= prefix from strings.
  + Fixed jump to bottom when selecting thumbnails with mouse.
  + gThumb opens import tool if the import tool is already opened.
  + Image viewer: fixed bright line visual artifacts.
  + Search:
  - Fixed possible crash after cancelling a search.
  - Do not count duplicated files.
  - Stop the previous search before starting the new one.
  - Stop searching if the user changes location.
  + Updated translations.
* Mon Sep 21 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.10.1:
  + User visible changes:
  - Exit fullscreen when pressing Esc in fullscreen mode.
  - Search editor: focus the newly added filter selector.
  - File list: reset vertical scroll position after changing
    directory.
  - Preferences dialog: increase width for extensions and
    shortcuts lists.
  + Bugs fixed:
  - WebP loader: fixed an infinite loop when the operation is
    cancelled.
  - Jpeg loader: fixed crash in case of some malformed jpegs.
  - Fixed crash when selecting other images after deleting.
  - Fixed long UI freeze after cutting/pasting many files.
  + Updated translations.
* Sun Apr 19 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.10.0:
  + New features and user visible changes:
  - Edit metadata dialogs: moved the lock button on the header
    bar; show the navigation bar only when the lock button is
    active.
  - Open location dialog: allow to use tilde as a home folder
    shortcut.
  + Bugs fixed: Install missing .ui file.
  + Updated translations.
- Changes from version 3.9.1:
  + New features and user visible changes:
  - Added ability to customize the keyboard shortcuts.
  - Added a shortcuts window to show the available shortcuts.
  - Added option to change the mouse wheel action.
  - Image viewer: added ability to define the transparency style.
  - Video viewer: allow to view the video at the original size;
    show the zoom factor in the statusbar.
  - Edit comment/tags dialogs: use the header bar; allow to
    change the current image from the dialog.
  - Add to catalog: use the header bar; allow to change the
    current image from the dialog.
  - Search: added ability to search in multiple folders.
  - Scripts: added %%T to insert a timestamp in the command.
  - Folder tree:
    . Better drag&drop support: allow to move a catalog into a
    library, and a library into another library, show an error
    if the drop operation is not possible;
    . Added an 'Open in Terminal' command in the context menu.
  - Overwrite dialog: show video previews as well, fixed dialog
    size.
  - Preferences: allow to specify a catalog or any other location
    as startup location.
  - Trash/Delete files: show progress for long operations.
  - File properties:
    . Added the file size in bytes.
    . Added a context menu command to customize the visibile
    properties.
  - Toolbar: show edit comment/tags in browser mode as well.
  - Export tools: removed from the toolbar. Some tools moved to
    the tools menu, others as a submenu in the gears menu.
  - Fixed window size when started the first time.
  - Updated app icon to follow the new GNOME style.
  - Rewritten README in markdown, updated screenshots.
  - Appdata: added release and OARS tags for flathub
    compatibility.
  + Bugs fixed:
  - gThumb hangs when some mount point is unavailable.
  - Jpeg loader: crash when the original size is too big for a
    cairo surface.
  - PNG loader: correctly load images with transparency.
  - Fixed run-time errors if exiv2 is not used.
  - Catalog: preserve the list order after saving the properties.
  - Scripts: fixed task cancellation when using a shell script.
  + Source code:
  - Utility functions refactoring.
  - Added tests for the utility functions.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Mon Dec 23 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.8.3:
  + App icons: name the app icons with the application id.
  + Jpeg loader: crash when the original size is too big for a
    cairo surface.
  + Fixed run-time errors if exiv2 is not used.
  + Fixed window size the first time gThumb is executed.
* Mon Nov 18 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.8.2:
  + User visible changes:
  - Use menus instead of popovers for menu buttons on the header
    bar, to show icons and accelerators.
  - Header bar: align menus to the right for menu buttons on the
    right side.
  - Tools menu: show the accelerators.
  - Search: show the matching files during the search operation.
  - Rename dialog: activate on enter.
  + Bugs fixed:
  - Fixed filesize test for big files.
  - Overwrite dialog: do not show an error after cancelling the
    operation.
  - Fixed crash when moving files to the trash.
  - Install missing UI files.
  - Added image/webp support in .desktop file.
  - Fix callback signature for value-changed signal when setting
    zoom.
  - Help: corrected wiki link.
  + Updated translations.
* Mon Sep  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.8.1:
  + Bugs fixed: Selections: fixed possible crash after reordering
    the files.
  + Updated translations.
* Mon May 27 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.8.0:
  + Delete dialog: make the delete button red.
  + Bugs fixed: build error when JPEG_LIB_VERSION < 80.
- Drop gthumb-exiv-0.27.patch: Fixed upstream.
* Mon Mar  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add meson_test macro in check section, run tests.
* Mon Mar  4 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to version 3.7.1
  + New features and user visible changes:
  - Removed the application menu.
  - Sidebar: show the property views in expandable sections.
  - Thumbnail list: spread the thumbnails horizontally to fill
    the available space.
  - Video viewer: added option to use opengl instead of cairo.
  - Show the rating as a sequence of stars.
  - Color picker: use lowercase letters for the hexadecimal
    value.
  - Contact sheet: set the current directory as destination if
    possible.
  - Script dialog: wider list to make all columns visible.
  - Use meson as build system.
  + Bugs fixed:
  - Image navigator: fixed popup positioning.
  - Preferences: fixed crash when setting the current location as
    default.
  - About dialog: fixed website url.
  - Jeg loader: try to load broken images.
  - Contact sheet: error if the theme file could not be loaded.
  - Removed deprecated functions.
- Removed
  0001-contact-sheet-error-if-the-theme-file-could-not-be-l.patch
  because fix has been included in this release.
- Switch to meson build system, add meson BuildRequires and macros.
* Tue Jan 29 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Add gthumb-exiv-0.27.patch: Fix build against exiv 0.27.
* Mon Jan 14 2019 Dan Čermák <dcermak@suse.com>
- Drop fix_double_free_dlg-contact-sheet_c.patch.
- Add
  0001-contact-sheet-error-if-the-theme-file-could-not-be-l.patch:
  upstream fix for bsc#1113749 / CVE-2018-18718 /
  glgo#GNOME/gthumb#18.
* Wed Dec 19 2018 Dan Čermák <dcermak@suse.com>
- Add fix_double_free_dlg-contact-sheet_c.patch:
  fix for bsc#1113749 / CVE-2018-18718
* Wed Oct  3 2018 bjorn.lie@gmail.com
- Update to version 3.6.2:
  + Updated links to wiki page.
  + Desktop background: fixed the way to obtain the monitor
    geometry.
  + Recognize the asf mime type as a video format.
  + Image loader: fixed memory leak when the operation was
    cancelled.
  + Avoid flickering when scaling the image takes some time.
  + Image navigator: fixed popup positioning.
  + Do not crash when loading broken jpeg images.
  + Preferences: fixed crash when setting the current location as
    default.
  + Updated translations.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Wed Mar 14 2018 luc14n0@linuxmail.org
- Update to version 3.6.1:
  + Bug fixed: Fixed crash when browsing folders with images and
    videos (bgo#760214).
  + Updated manual translations.
  + Updated translations.
- Add pkgconfig(json-glib-1.0) BuildRequires to avoid implicit
  dependencies.
- Drop update-desktop-files BuildRequires and suse_update_desktop_\
  file macro: they are no longer required.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Nov 21 2017 luc14n0@linuxmail.org
- Update to version 3.6.0:
  + Bugs fixed: Numeric keypad nav keys don't work (bgo#667390).
- Readd bison, flex and itstool BuildRequires since configures
  actually do check for them.
* Mon Nov  6 2017 luc14n0@linuxmail.org
- Update to version 3.5.4:
  + Bugs fixed:
  - No application icon on Wayland.
  - Tags dialog: improved usability. Do not select the entry
    content after opening the dialog; add a comma at the end of
    the tags entry to simplify the addition of a new tag; support
    keyboard navigation (bgo#777234).
  - Hi-DPI: "High" quality zoom is pixelated on hi-dpi monitors
    (bgo#779340).
  - Web services: fixed errors and removed features no longer
    supported by the APIs:
    . Facebook: fixed authorization process; removed photo
    importer.
    . PicasaWeb: removed album creation; remember application
    authorization (bgo#784142).
    . Photobucket: removed uploader.
  - Image viewer: use a white background for transparency
    (bgo#780207).
  - Fixed saving of uris in settings (bgo#783498).
  - Color manager: fixed crash when no device is found
    (bgo#789347).
  - Do not save selections. This broke workflows where selections
    were involved.
  - Removed obsolete file gthumb.convert (bgo#767034).
  + Updated manual translations.
  + Updated translations.
- Update Url to https://wiki.gnome.org/Apps/gthumb: current
  gThumb's web page.
- Point fdupes to the data directory instead of the build root,
  which is a practice that must be avoided.
- Drop pkgconfig(sm) and its --with-smclient=xsmp configure
  parameter: not needed/used anymore since its parameter no longer
  exist.
- Drop bison, flex, pkgconfig(ice) and itstool BuildRequires: they
  are not needed/used anymore.
- Replace pkgconfig(libsoup-gnome-2.4) with pkgconfig(libsoup-2.4):
  libsoup is the required dependency and was already in use. They
  are different files but live in the same package-devel.
* Wed Oct  4 2017 luc14n0@linuxmail.org
- Update to version 3.5.3:
  + New features and user visible changes:
  - Add app menu entries to the gear menu if the app menu is not
    supported by the desktop environment.
  - Updated appdata file.
  - Fixed help markup.
  + Updated manual translations.
  + Updated translations.
- Change devel's package group to Development/Libraries/GNOME:
  correction.
- Drop %%desktop_database_*, %%icon_theme_cache_* and
  %%glib2_gsettings_schema_* post/postun/requires: functionality now
  covered by file triggers.
- Upstream's file rename of: gthumb.appdata.xml to
  org.gnome.gThumb.appdata.xml, gthumb.desktop to org.gnome.gThumb
  and gthumb-import to org.gnome.gThumb.Import.
* Thu Aug 31 2017 zaitor@opensuse.org
- Add conditional export CFLAGS and CXXFLAGS == -std=gnu99 when
  building for Leap, needed with version 3.5.2.
- Add a export CXXFLAGS="-fPIE %%optflags" to ensure that pie is
  enabled also for gcc-c++.
* Tue Aug 15 2017 zaitor@opensuse.org
- Update to version 3.5.2:
  + New features and user visible changes:
  - Faster image loading.
  - Fixed big memory leak and other minor memory leaks.
  - Aspect ratio filtering.
  - Video player works on wayland as well.
  - Color profiles work on wayland as well (requires colord).
  - Show the color profile description in the property view.
  - Headerbar: show the tools menu button in viewer mode as well;
    added a button to go to the catalogs root; added a button to
    go to the home folder.
  - Scripts: allow to specify a generic accelerator.
  - Selections: save at exit and restore at start.
  - Video player: added a loop button.
  - Use Unicode in translatable strings (bgo#782038).
  + Bugs fixed:
  - Slideshow: no need to specify autoaudiosink as audio-sink. It
    is already the default audio sink (bgo#785612).
  - SEGFAULT when a svg image could not be loaded (bgo#784886).
  - Do not process bitmap thumbnails with invalid color settings
    (bgo#778556).
  - Fixed possible crash when switching from the image viewer to
    another viewer.
  + Updated translations.
- Add pkgconfig(colord) BuildRequires: New optional dependency.
- Drop obsolete clean section.
* Tue Jul 25 2017 meissner@suse.com
- Forcefully enable PIE in the spec file, as the configure uses
  - fPIC, which disables are automatism.
* Tue Feb 28 2017 zaitor@opensuse.org
- Update to version 3.5.1:
  + New features and user visible changes:
  - Added support for double click activation.
  - Added option to open files in fullscreen mode.
  - Added a zoom popover with various zoom commands and a zoom
    slider.
  - Added a color picker.
  - All dialogs: use the headerbar if supported by the desktop
    environment (if 'gtk-dialogs-use-header' is set).
  - App menu: added 'keyboard shortcuts'.
  - Tag filter: added ability to filter using a regular
    expression.
  - Sort catalogs by name, then by date.
  - Gif animations: allow to pause and view the next frame.
  - Added the control-o accelerator to open the location dialog.
  - Keep the zoom buttons on the headerbar if the tool allow to
    zoom the image.
  - Added a fullscreen button to the headerbar in viewer mode.
  - Find duplicates: speed optimizations.
  - New folder: open the folder after creating it.
  - Hide the image frame when in fullscreen mode.
  - Moved the photo importer preferences to the extension
    section.
  - Find duplicates: more responsive when the duplicate list is
    huge.
  - Added support for image/x-fuji-raf raw files (bgo#709385).
  - Fixed RTL icons and arrow rendering (bgo#747380).
  + Bugs fixed:
  - Ensure the settings have been saved before exiting.
  - Desktop background: always create a unique filename to force
    an update.
  - Desktop background: fixed error when setting an xcf image as
    background.
  - Resize: fixed wrong aspect ratio after opening.
  - Slideshow: start on the same monitor of the window.
  - Sizing issues in gthumb preferences under gtk+ git master
    (bgo#770546).
  - Adjust contrast: better description of the stretch method
    (bgo#767615).
  - Removed deprecated gnome-common macros (bgo#768528).
  - Fixed scrollbars resetting their position when changing
    image.
  - Fixed theme errors with gtk+ 3.20.
  - Do not show rotation tools for animations.
  - Crash after pressing shift-arrow (bgo#760050).
  - Stopping slideshow freezes entire program (bgo#759787).
  - Disambiguate labels of various metadata "date" fields
    (bgo#728471).
  - Crash if trying to delete image on sftp mounted (bgo#759727).
  - Crash when deleting duplicate (bgo#750142).
  - Various minor typos fixed (bgo#756486).
  + Updated translations.
- Drop gnome-common BuildRequires, we do not carry any patches.
* Wed Oct 12 2016 zaitor@opensuse.org
- Update to version 3.4.4.1:
  + gthumb 3.4.4 fails post build check 64bit-portability-issue
    (bgo#772739).
- Drop gthumb-implicit-declarations.patch: Fixed upstream.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Mon Oct 10 2016 zaitor@opensuse.org
- Update to version 3.4.4:
  + Sizing issues in gthumb preferences under gtk+ git master
    (bgo#770546).
  + Hide the image frame when in fullscreen mode (bgo#767731).
  + Fixed headerbar buttons not shown correctly after activating a
    tool.
  + Orginaze files: fixed wrong catalog cardinality.
  + Fixed scrollbars resetting their position when changing image.
  + Find duplicates: faster.
  + New folder: open the created folder.
  + Print dialog: expand the options side to make the zoom slider
    visible.
  + Fixed wrong image loaded after deleting an image from a
    catalog.
  + Updated translations.
- Add gthumb-implicit-declarations.patch: Fix implcit declaration
  when building the image_viewer extension.
* Tue Apr 12 2016 zaitor@opensuse.org
- Update to version 3.4.3:
  + Bugs fixed:
  - Theme errors with gtk+ 3.20.
  - Viewer sidebar too wide.
  + Updated translations.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.4.2:
  + User visible changes: Sort catalogs first by name then by date,
    instead of doing the opposite.
  + Bugs fixed:
  - Crash after pressing shift-arrow (bgo#760050).
  - Stopping slideshow freezes entire program (bgo#759787).
  - Crash if trying to delete image on sftp mounted (bgo#759727).
  - Crash when deleting duplicate (bgo#759631).
  - Crash after changing and renaming file (bgo#750142).
  + Updated translations.
* Wed Sep 23 2015 zaitor@opensuse.org
- Update to version 3.4.1:
  + Fixed build on Fedora 23 (bgo#747982).
  + Allow cross-compiling (bgo#755390).
  + Updated translations.
* Fri Aug 14 2015 dimstar@opensuse.org
- Fix build on Leap: webkit2gtk-4.0 already exists there. This
  change breaks building on pure SLE12.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.4.0:
  + Media player: smoother volume change.
  + History: do not remove other occurrences of the current
    location.
  + Don't merge translations into gschema file.
  + Facebook: fixed the authorization process.
  + Contact sheet: fixed header color not set when creating a new
    theme.
  + Updated translations.
* Sun Apr  5 2015 zaitor@opensuse.org
- Update to version 3.3.4:
  + New features and user visible changes:
  - Image viewer: added 'fit to height' button.
  - Drag&Drop: move files by default.
  - Ask confirmation before moving files with a drag&drop
    operation.
  - Make 'delete files' and 'trash files' asyncronous.
  - Use the default gtk+ style for message dialogs.  Use the
    header-bar for request dialogs.
  - Changed 'adjust contrast' shortcut to 'a'. 'h' is now used to
    fit to height.
  - Added a symbolic application icon.
  - Fixed comment pane style with gtk+ 3.16.
  - Show the app menu on the headerbar if the shell doesn't show
    it.
  - Preferences dialog: fixed extensions activation/deactivation.
  + Bugs fixed:
  - Webalbums: do not exit if a fatal error is issued
    (bgo#744530).
  - Build failure on x32 (kilobyte).
  - Image viewer: the overview quickly appears and disappears
    sometimes.
  + Updated translations.
* Tue Feb 10 2015 zaitor@opensuse.org
- Update to version 3.3.3:
  + New features and user visible changes:
  - Allow to apply the embedded color profile for jpeg images.
  - New image tools: special effects; curves.
  - Unified 'equalize histogram' and 'adjust contrast': show a
    preview of the various contrast filters.
  - Grayscale tool: show a preview of the different filters.
  - Fixed the interface style when used with gtk+ 3.14
  - File propery view: use a switcher; added a details page that
    show all the metadata, show only the important exif fields in
    the properties page.
  - UI changes to the preferences dialog: use a sidebar instead
    of a notebook to avoid a large dialog with some translations;
    better spacing; removed the Ok button.
  - Video player: save the screenshot without showing the dialog.
  - Allow to set the screenshots location in the extension
    preferences dialog.
  - Show a message in the statusbar after saving.
  - Gear menu: use the new icon if using gtk+ 3.13 or newer.
  + Bugs fixed:
  - video player: do not hide the mediabar when using the volume
    control.
  - Forbidden when trying to upload to Flickr (bgo#732557).
  - Build against either webkit2gtk-3.0 or webkit2gtk-4.0.
  + Updated translations.
- Drop gthumb-webkit2gtk.patch,
  gthumb-new-icon-for-gear-menu.patch and
  gthumb-fix-forbidden-flicker-upload.patch, Fixed upstream.
- Following above change: remove gnome-common BuildRequires and
  call to gnome-autogen.sh, as we no longer carry any patches.
- Add pkgconfig(lcms2) BuildRequires: Build the new optional LCMS2
  support.
* Sat Aug 23 2014 dimstar@opensuse.org
- Add gthumb-webkit2gtk.patch: Support building against
  webkit2gtk-3.0 and webkit2gtk-4.0.
- Add gnome-common BuildRequires and call to gnome-autogen.sh, as
  above patch touches the build system.
- Add conditional pkgconfig(webkit2gtk-4.0) BuildRequires for 13.2
  and newer.
* Sat Aug  9 2014 zaitor@opensuse.org
- Update to version 3.3.2:
  + Bugs fixed:
  - Allow the user to edit tags using the contextual menu also
    (bgo#728467).
  - Special directories: added DOWNLOAD, removed DESKTOP
    (bgo#728445, bgo#728446).
  - Web album: fixed thumbnail size (bgo#727775).
  - Desktop background: use the stretched option in some cases
    (bgo#726708).
  - Make copy and paste in same folder equivalent to duplicating
    (bgo#722726).
  - Can view tiff files, but can not print (bgo#726260).
  - image viewer: use a smaller frame border (bgo#726091).
  - Extra image appears in image viewer (bgo#722631).
  - Added AppData file for GNOME Software Center (bgo#722770).
  - Ctrl+P doesn't work (bgo#722707).
  - Script editor: help buttons don't work (bgo#722925).
  - Toolbox: Fix the undo and the redo symbols in RTL
    (bgo#723542).
  - Sharpen: Fix the undo symbols in RTL (bgo#723542).
  - Rotate image: Fix the undo symbols in RTL (bgo#723542).
  - Adjust colors: Fix the undo symbols in RTL (bgo#723542).
  - Updated obsolete info in license text (bgo#721455).
  - gThumb doesn't honour privacy settings (bgo#722349).
  - Remove unnecessary gdkx.h include from gth-screensaver
    (bgo#597594).
  - Use unity-control-center if in Unity (bgo#722233).
  - Fix build failing without libtiff installed (bgo#722183).
  - Cannot Save As with uppercase .JPG (bgo#721281).
  + Updated translations.
- Add gthumb-new-icon-for-gear-menu.patch, use the new icon with
  GNOME 3.13 and newer.
- Add gthumb-fix-forbidden-flicker-upload.patch, fix forbidden when
  trying to upload to flicker.
* Sun Jan 19 2014 zaitor@opensuse.org
- Update to version 3.3.1:
  + New features and user visible changes:
  - Use a GtkHeaderBar instead of a menu and a toolbar.
  - Use the dark theme.
  - Better raw image support, using libraw instead of libopenraw.
  - Image viewer: show a frame around the image; use an overview
    window to scroll the image instead of the scrollbars; better
    quality for zoomed out images.
  - Faster image loader for big images.
  - Media player: hide the mediabar after a timeout.
  - Filterbar: added buttons to view the selections.
  - File properties: show only the basic properties, allow to
    show all of them.
  - Image tools: use a grid layout for the buttons.
  - Use a separate dialog for the file tool options.
  - Use symbolic icons everywhere.
  - Added a custom tiff loader.
  - Add a rating-based filter.
  - App menu: removed 'keyboard shortcuts'.
  - Histogram view: save and restore the scale type.
  + Bugs fixed:
  - Help: fix calling help from withing the application
    (bgo#710573).
  - Fixed saving of TGA files.
  - Fixed the video player stopping after saving a screenshot.
  - Rotating image destroys XMP and IPTC metadata (bgo#719622).
  - Command line ignored for the second window (bgo#712716).
  - Empty Options dialog after Canceling it once (bgo#711788).
  - Buttons with label toolbutton1 and toolbutton2 in Bookmark
    window (bgo#711777).
  - Default parameters for image resizing are misleading
    (bgo#710479).
  - Fixed broken window layout with gtk+ 3.10 (bgo#708800).
  - Find duplicates: fixed crash when using a predefined
    directory (bgo#706697).
  - gThumb crashes when attempting to play a video (bgo#706343).
  - Flickr: allow to use a facebook or google account
    (bgo#703534).
  - Thumbnail list: images drawn with wrong offset (bgo#702538).
  - Facebook: fixed authentication.
  - configure: fixed unrecognized option --disable-libjson-glib
    (bgo#696783).
  - Removed the use of many deprecated functions.
  + Updated manual translations.
  + Updated translations.
- Exchange pkgconfig(libopenraw-1.0) for pkgconfig(libraw)
  BuildRequires, and pass --enable-libraw instead of
  - -enable-libopenraw to configure, following upstream change.
- Drop obsolete conditionals from post/postun.
* Tue Nov 26 2013 dimstar@opensuse.org
- Update to version 3.2.5:
  + Media viewer: fixed progress bar behaviour in gtk+ 3.10.
  + Empty file format options dialog after canceling it once
    (bgo#711788).
  + Fixed endless image reloading for some images.
  + Fixed display of the manual.
  + Default parameters for image resizing are misleading
    (bgo#710479).
- Drop gthumb-launch-help.patch: fixed upstream.
* Mon Oct 21 2013 dimstar@opensuse.org
- Add gthumb-launch-help.patch: Fix help not being found
  (bnc#846900).
* Thu Oct 17 2013 firebird209@gmail.com
- Update to version 3.2.4:
  + Fixed error when rotating jpeg images (bgo#709698).
  + Fixed broken window layout with gtk+ 3.10 (bgo#708800,
    bnc#846626).
  + Fixed crash when opening the preferences dialog.
  + Find duplicates: fixed crash when using a predefined directory
    (bgo#706697).
  + Fixed crash when attempting to play a video under special
    circumstances (bgo#706343).
  + Fixed crash when copying or moving files (bgo#705877).
  + Updated translations.
- Add pkgconfig(gstreamer-video-1.0) BuildRequires: new dependency.
* Sun Sep 22 2013 zaitor@opensuse.org
- Add pkgconfig(webkit2gtk-3.0) BuildRequires in order to build web
  services support.
* Wed Jul 10 2013 zaitor@opensuse.org
- Update to version 3.2.3:
  + Flickr: allow to use a facebook or google account (bgo#703534).
  + Thumbnail list: images drawn with wrong offset (bgo#702538).
  + Fixed the video player stopping after saving a screenshot.
  + Fixed saving of TGA images.
  + Fixed the size of the toolbar in fullscreen mode.
  + Show the cursor again after stopping the slideshow.
  + Web services: do not delete the previous account when creating
    a new one.
  + Updated translations.
* Tue May 14 2013 dimstar@opensuse.org
- Update to version 3.2.2:
  + Resize, Convert: correctly set the destination folder.
  + Fixed the file list style with Gtk+ 3.8.
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 3.2.1:
  + Facebook: fixed authentication.
  + Slideshow: fixed audio playback.
  + Filter-bar: fixed the spin button width for the file size
    control.
  + Bookmarks: fixed ability to modify the bookmarks.
  + Image viewer: allow to use button 2 to drag the image.
  + Fixed unrecognized configure option --disable-libjson-glib
    (bgo#696783).
* Thu Mar 28 2013 zaitor@opensuse.org
- Update to version 3.2.0:
  + Added ability load xcf images.
  + Always use a dark background in the image viewer.
  + Updated translations.
* Sat Mar 16 2013 zaitor@opensuse.org
- Update to version 3.1.4:
  + Fixed creation of blur thumbnails for jpeg images
  + Updated translations.
* Sat Feb  9 2013 zaitor@opensuse.org
- Update to version 3.1.3:
  + New features and user visible changes:
  - Fixed uploading to Facebook and all other web services.
  - Added ability to import photos from Facebook.
  - Save and restore the thumbnail list size.
  - Selections: Pressing control-n (with n in 1,2,3) again goes
    back to the previous view.
  - Monitor all the expanded locations in the folder tree.
  - Show a progress dialog for long saving operations.
  - Added keybindings to delete files in catalog view:
    control+delete moves to trash; shift+delete deletes from
    disk.
  - Allow to delete the tags from the default tag list.
  + Bugs fixed:
  - Web album export produces invalid HTML. (bgo#691123).
  - Fixed thumbnail generation for rotated images.
  - Fixed the thumbnail style in gtk 3.6.
  - Video viewer: fixed progress bar for gtk 3.6.
  - webp: fixed build for Big-Endian systems. (#bgo#691309).
  + Internal code changes:
  - Ported to GStreamer 1.0.
  - Ported to libsecret.
  + Updated translations.
- Add itstool, pkgconfig(gstreamer-1.0),
  pkgconfig(gstreamer-plugins-base-1.0) and pkgconfig(libsecret-1)
  BuildRequires, new dependencys due to upstream port to GST-1.0 and
  libsecret.
- Drop pkgconfig(gstreamer-0.10),
  pkgconfig(gstreamer-interfaces-0.10) and
  pkgconfig(gnome-keyring-1) BuildRequires, following above port.
- Drop gthumb-bigendian-typo.patch, fixed upstream.
- Drop obsolete --disable-scrollkeeper configure option.
* Mon Feb  4 2013 dimstar@opensuse.org
- No longer move sr@Latn to sr@latin: sr@latin is correctly being
  created and the move would 'only' move the incomplete / wrong
  translation inside sr@latin. Our scritps take care of removing
  incomplete translations.
* Fri Dec 28 2012 dvaleev@suse.com
- Add gthumb-bigendian-typo.patch: fix missing ; in BigEndian case.
* Mon Oct 15 2012 zaitor@opensuse.org
- Update to version 3.1.2:
  + Bugs fixed:
  - Fixed images scaling producing black images.
  - Use gdk-3.0 to check the GDK target (bgo#685674)
  + Updated translations.
* Sun Sep 23 2012 dimstar@opensuse.org
- Update to version 3.1.1:
  + New features and user visible changes:
  - Added ability to load and save WebP images.
  - Allow to specify the format options when saving a file (can
    be disabled).
  - Save and restore the window maximized state, the filterbar
    status, the visited locations history and the viewer sidebar
    status.
  - Image viewer: use the dark background by default, and use a
    more neutral color instead of black.
  - Video viewer: save and restore the volume level.
  - Read system bookmarks from XDG_CONFIG_HOME/gtk-3.0/bookmarks.
    Fallback to ~/.gtk-bookmarks if the new file is not found.
    (bgo#675401)
  - Use XDG_CACHE_HOME/thumbnails as thumbnail cache. Fallback to
    the old ~/.thumbnails directory if the new directory doesn't
    exists.
  - File list: align the caption to the left and use a smaller
    font.
  - Browser: show loading errors in the info bar instead of using
    a modal dialog.
  - Added automatic completion to the category entry.
  - Rotation tool: allow to rotate an image from -180 to 180
    degrees.
  - Selections: allow to cut the files.
  - Added a menu item to hide/show the file properties.
  - Print: set a good default filename for the print-to-file
    operation.
  - Enhance colors: use a faster algorithm and rename to "Adjust
    Contrast".
  - Equalize histogram: use a faster algorithm.
  - Desaturate tool: added ability to choose the method to use,
    renamed to "Grayscale".
  - Removed the format chooser from the file dialog.
  - Added an high resolution application icon.
  - Add an application menu if used with GNOME Shell.
  + Bugs fixed:
  - Fixed image quality when the zoom factor is smaller then 0.5.
    (bgo#674159)
  - Do not make modal dialogs block other windows as well.
  - Find duplicates: remember the checked state when filtering
    the file list. (bgo#679191)
  - Sort by name if the date is the same. (bgo#676263)
  + Updated translations.
- Add pkgconfig(libwebp) BuildRequires: new dependency.
* Fri Sep 14 2012 vuntz@opensuse.org
- Update to version 3.0.2:
  + Bugs fixed:
  - Fixed fullscreen toolbars with multiple monitors.
  - Fixed error when rotating keeping the origina size.
  - Photobucket exporter: fixed crash when closing the dialog.
  - Fixed broken video thumbnail (bgo#666303)
  - Delete key does nothing when image first opened (bgo#678441)
  - Picasa Web exporter: images not displayed in the export
    dialog (bgo#679546)
  - Fix parallel build problems with enum generation.
  + Updated translations.
* Tue May 15 2012 vuntz@opensuse.org
- Update to version 3.0.1:
  + Bugs fixed:
  - Resize images: correctly restore the last used width and
    height (bgo#675498)
  - Preserve XMP lists when saving an image. (bgo#674908)
  - Fixed loading of thumbnails after re-enabling thumbnails
    again.
  - Fixed mouse wheel navigation with the video viewer.
  - Added a man page.
  + Updated translations.
- Add pkgconfig(gsettings-desktop-schemas) BuildRequires: new
  dependency upstream.
* Sun Apr 29 2012 dimstar@opensuse.org
- Update to version 3.0.0:
  + Metadata category names WON'T show translated strings
    (bgo#674033)
  + Selections: fixed keyboard shortcuts for some keyboard layouts.
    (bgo#673872)
  + Fixed compilation without libjpeg.
  + Ignore extensions with a different API version.
  + Fixed file navigation with the mouse wheel with Gtk+ 3.4.0 or
    greater.
  + Fixed possible crash when changing location.
  + Updated translations.
* Thu Apr 26 2012 vuntz@opensuse.org
- Change pkgconfig(libsoup-2.4) BuildRequires to
  pkgconfig(libsoup-gnome-2.4) as it offers additional features.
* Wed Apr 11 2012 dimstar@opensuse.org
- Update to version 2.90.3:
  + New features and user visible changes:
  - Selections: fixed reordering of files.
  - Added command Alt+Shift+n to remove files from selection n.
  - Added a command to open the original folder.
  - Show an emblem when a file is added to a selection.
  + Bugs fixed:
  - Require exiv2 version 0.21. since the code uses Exiv2::LogMsg
    (bgo#673711)
  - Removed potentially dangerous strncpy (bgo#672866)
  - Fixed possible crash when changing directory quickly.
  - Fixed possible crash after closing the context menu in the
    folder tree.
  - Fixed run-time warning when uninhibiting the screensaver.
  + Updated translations.
* Thu Mar 29 2012 dimstar@opensuse.org
- Update to version 2.90.2:
  + New features and user visible changes:
  - Added a Location dialog to enter the path to display.
  - Copy/Move dialog: save the list of the last 10 choosed
    folders.
  - Added a tool to import the embedded metadata in the gThumb
    comment system.
  - Map view: added a scale on the map.
  + Bugs fixes:
  - Show "Moving" instead of "Copying" when moving a file.
  - Fixed some performance issues when updating thumbnails.
  - Fixed many memory leaks.
  + Other bugs fixed: bgo#672184, bgo#671940, bgo#671892,
    bgo#671451
  + Updated translations.
- Drop gthumb-gdk_window.patch: fixed upstream.
* Fri Mar  9 2012 dimstar@opensuse.org
- Update to version 2.90.1:
  + New features and user visible changes:
  - Added 'selections' as a more powerful way to select files.
  - High quality zoom for SVG images.
  - Comment and tags dialogs: allow to save the metadata without
    closing the dialog.
  - Added option to reuse the active window when opening files
    from an external application.
  - Allow to hide/show the file properties pane.
  - Allow to change the position of the file properties in
    browser mode.
  - Save the image keyworks in the Xmp.dc.subject tag as well.
  - Save the Exif.Image.Software tag only if the content was
    modified.
  - Sync the rating with the Xmp.xmp.Rating tag.
  - Video viewer: jump to the specified position when clicking on
    the progress bar.
  - Video viewer: use symbolic icons for the play button and the
    volume control.
  - Make the 'shrink wrap' command work for the video viewer as
    well.
  - Image viewer: hide the horizontal scrollbar in 'fit width'
    mode
  - Image viewer: implemented the checked transparency.
  - Show the Edit button in browser mode as well
  - Moved the location chooser above the file list.
  - Preferences: show the slideshow preferences in the viewer tab
    to save some horizontal space.
  - Use the PICTURES special dir as the default startup location.
  + Internal changes:
  - Ported to Gtk+ 3
  - Ported from GConf to GSettings.
  - Ported from libunique to GtkApplication.
  - Ported to libchamplain version 0.12.
  - Removed use of deprecated functions.
  - Use the G_DEFINE_* macros to define GObject classes.
  - Added a custom widget to display the thumbnail list instead
    of GtkIconView.
  + Updated translations.
- Remove xz BuildRequires as it now comes for free in the build
  system.
- Remove no longer needed BuildRequires: gconf2-devel, gtk2-devel,
  pkgconfig(unique-1.0).
- Add pkgconfig(gtk+-3.0), pkgconfig(zlib) BuildRequires, following
  the code port to GTK+ 3.
- Add pkgconfig(librsvg-2.0) BuildRequires for the new high quality
  zoom for SVG images.
- Convert -devel BuildRequires to pkgconfig() style ones:
  + Old ones: brasero-devel, clutter-devel, clutter-gtk-devel,
    libopenraw-devel, libsoup-devel gstreamer-0_10-devel,
    gstreamer-0_10-plugins-base-devel, libexiv2-devel,
    libgnome-keyring-devel.
  + New ones: clutter-1.0, clutter-gtk-1.0, exiv2, gnome-keyring-1,
    gstreamer-0.10, gstreamer-interfaces-0.10, libbrasero-burn3,
    libopenraw-1.0, libsoup-2.4.
- Add pkgconfig() BuildRequires that were implicitly brought in
  before: gio-unix-2.0, glib-2.0. gmodule-2.0, gthread-2.0, libpng.
- Pass --with-smclient=xsmp to configure to make sure we enable
  session management.
- Remove --disable-schema-install configure parameter, as it is no
  longer known after GSettings port.
- Replace gconf_schemas_* macros with gsettings_* after GSettings
  port.
- Add gthumb-gdk_window.patch: Fix build with gtk 3.3.18.
* Mon Feb 20 2012 dimstar@opensuse.org
- Add pkgconfig(ice) and pkgconfig(sm) BuildRequires: they used to
  be pulled in by something else, but the xorg-x11 relayout changed
  that.
* Mon Jan 23 2012 zaitor@opensuse.org
- Update to version 2.14.2:
  + Fixed memory leak in 'Adjust Colors'. (bgo#667931)
  + Fixed renaming of folders and catalogs.
  + Fixed names of the gconf keys for the 'change date' tool.
  + Fixed possible crash on startup.
  + Updated translations.
* Sun Dec  4 2011 zaitor@opensuse.org
- Update to version 2.14.1:
  + Fixed infinite reloading of some images when selected in the
    file list.
  + Fixed export to Photobucket.
  + Fixed crash when no file properties view is registered.
  + Fixed crash when closing the media viewer very quickly.
  + Fixed some memory leaks.
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Mon Nov  7 2011 dimstar@opensuse.org
- Update to version 2.14.0:
  + Resize images: when resizing a single image update the second
    dimension if the ratio is fixed. (bgo#662397)
  + Faster image loading if the file is not local (bgo#655471)
  + File selection not updated in status bar when using thumbnail
    side panel (bgo#660430)
  + Updated translations.
* Thu Sep 29 2011 vuntz@opensuse.org
- Update to version 2.13.91:
  + Bugs fixed:
  - Fixed iptc fields order in the print dialog. (bgo#659820)
  + Updated translations.
* Wed Sep 14 2011 vuntz@opensuse.org
- Update to version 2.13.90:
  + Bugs fixed:
  - Added ability to import from and export to 23hq.com
    (bgo#657269).
  - Web uploaders: update the progress bar during the upload;
    allow to cancel an upload.
  - Fixed selection of the destination folder in the import
    dialog (bgo#657557).
  - Fixed comment synchronization when a \r character is in the
    text.
  - Flickr importer: fixed import of photosets greater then 500
    photos (bgo#648701).
  - Facebook uploader: allow to upload high resolution images
    (bgo#652216).
  - Fixed a crash when loading remote images.
* Thu Sep  1 2011 vuntz@opensuse.org
- Update to version 2.13.3:
  + New features and user visible changes:
  - Added ability to import photos from a folder. (bgo#452764)
  - Find duplicates: added ability to eliminate all the
    duplicates at once leaving only the newest or the oldest one.
    (bgo#342887)
  - Show the current disk free space in the status bar.
  - Make the keyboard editing shortcuts work from the file list
    as well.
  - Resize image: added buttons to set to the original image size
    or the screen size (bgo#639012)
  - Added "copy to" and "move to" commands in the folder list as
    well.
  - F2 renames the folder if the folder tree is focused
    (bgo#448588)
  - Web albums: always use subfolders. removed the relative
    option from the dialog (bgo#624334)
  - Allow %%F (filename) and %%C (comment) in Web Album headers and
    footers (bgo#166579)
  - Adjust colors: added a preview check button to compare the
    image with the original (bgo#566040)
  - Save and restore the settings in the change date dialog
    (bgo#451803)
  - Added Ctrl+Q to close all the windows.
  - Automatically select the last viewed file on startup if "Go
    to last visited folder or catalogue" option is active.
  - Ask confirmation before deleting a command/script
    (bgo#627475)
  - Increased the number of preloaded images. preload the next 4
    and the previous 4 images, instead of the next 2 and the
    previous one. (bgo#564017)
  - Improved insertion of files in catalogs: when using the paste
    command the files are inserted after the last selected file;
    when using drag&drop the files are inserted in the current
    position as when moving files inside a catalog. (bgo#371697)
  - Added "gThumb" to the window title (bgo#627159)
  + Bugs fixed:
  - Do not allow the user to create catalogs with a / in the name
    (bgo#652482)
  - Progress dialog: set the task description as dialog title if
    the main window is hidden (bgo#628769)
  - Web album: simplified code and fixed a memory leak
    (bgo#644970)
  - Fixed crash opening an image from command line (bgo#654241)
  - Use the FSF web site instead of the address in gthumb.h
    (bgo#652027)
  - Disabled refresh in viewer mode (bgo#627183)
  - Resize tool: reset size to sensible defaults when switching
    between %% and pixels (bgo#622427)
  - EXIF tags listed more than once when disabling and then
    re-enabling the EXIF extension (bgo#621454)
  - Give the focus to the viewer after changing the image
    (bgo#595575)
  - Image rotation: show the correct progress fraction and
    current file name in the progress dialog (bgo#594796)
  - Copying or moving a file will copy or move its XMP sidecar as
    well (bgo#581641)
  - Web albums: fixed hotkeys binding in the main dialog
    (bgo#575176)
  - Contact sheet: fixed some hotkey bindings in the main dialog
    (bgo#575171, bgo#575170)
  - Resize images: bind width and height if size is expressed in
    percentage and keep ratio is active (bgo#564827)
  - Exclude hidden folders from search result when view->hidden
    files is not active (bgo#502524)
  - Fixed crash when going fullscreen with no image in the file
    list
  + Updated translations.
* Tue Jun  7 2011 dimstar@opensuse.org
- Update to version 2.13.2:
  + New features and user visible changes:
  - Added a sharpen tool.
  - Added a tool to rotate images of any degree.
  - Added "copy image to clipboard" and "paste image from
    clipboard".
  - Added a map view to view the geographical position where the
    picture was taken.
  - Added tool to delete files metadata.
  - Disable the screensaver when playing videos or slideshows.
  - Crop: added ability to maximize and center the selection.
  - Rename series: added a dialog to edit the filename template.
  - Resize images: added ability to select the file format.
  - Slideshow: make the animations smoother.
  - Moved the extensions activation in the preferences dialog.
  - Pressing the delete key in a catalog removes the file from
    the catalog instead of deleting the file from disk
  - Image selector: show the active resize grip.
  - Red eye removal: exit from the tool only when the ok button
    is clicked.
  - Added VIDEO and DESKTOP directories to the entry point list.
  - Added the entry points to the bookmark menu as well.
  + Bugs fixed:
  - Fixed crash when closing a window while the video viewer is
    active.
  - Webalbums: fixed progress dialog not showing again after the
    first exporting.
  - Find duplicates: do not allow to select more than a file.
  - Fixed error when enabling/disabling thumbnails very fast.
  - Fixed renaming of files when the new name is entered quickly.
  - Correctly display images with wrong extension name.
  - Fixed the desktop background setting with GNOME 3.0 or higher
  - bgo#645515, bgo#644346, bgo#644344, bgo#651297
  + Updated translations.
* Mon May 16 2011 dimstar@opensuse.org
- Update to git snapshot from 2011.05.16 to fix build on Factory.
  New features and bug fixes from git will be listed on update to
  2.13.2.
* Mon May 16 2011 dimstar@opensuse.org
- Update to version 2.13.1:
  + New features and visible changes:
  - New tools: contact sheet creator, find duplicates.
  - Print: allow to specify the number of rows and columns; allow
    to specify the header and the footer of the pages.
  - Added "Copy to" and "Move to" commands to copy or move files
    to another directory. You can still accomplish the some task
    using the Copy/Cut/Paste commands.
  - Re-added the 2.10 semi-trasparent property box in fullscreen
    mode. The 'i' key shows/hides the property box.
  - Re-added ability to view file comments in the file list.
  - Preferences dialog: added option to specify the file
    extension to use when creating jpeg and tiff files.
  - Added a histogram view to the sidebar.
  - Added ability to drag files with the middle mouse button to
    allow the user to choose the action to perform.
  - Allow to rename the files in a catalog.
  - Added ability to move catalogs with drag&drop.
  - Change date tool: added the ability to shift dates by any
    offset.
  - Edit metadata dialog: added 'Iptc.Application2.ProvinceState'
    field to the 'Other' tab
  - Convert and resize: allow to specify a destination folder
    even when the images are from a catalog.
  - Video player: allow to change playback speed when paused.
  - Slideshow: show the paused sign centered on the screen and
    hide it after a second.
  - Crop tool: added a new grid mode to view the center lines of
    the current selection.
  - Added ability to search and filter files with a single tag.
  - Always use the same height for the thumbnails.  This allows
    to avoid scroll jumps when loading the thumbnails listed
    before the currently visible ones.
  - Changed the thumbnail style: use rounded corners.
  - Added a comment filter that ignores automatic camera comments
    such as "SONY DSC", "OLYMPUS DIGITAL CAMERA", etc.
  + Bugs fixed: bgo#632298, bgo#630279, bgo#633884, bgo#635948,
    bgo#635475, bgo#628098, bgo#572685, bgo#642848, bgo#627153.
  + Updated translations.
* Mon May 16 2011 coolo@opensuse.org
- Replace libunique-devel BuildRequires with pkgconfig(unique-1.0).
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Fri Jan 14 2011 vuntz@opensuse.org
- Update to version 2.12.2:
  + Correctly activate the default extensions when started the
    first time. (bgo#635475)
  + Enable building with exiv2-0.21 (bgo#349150)
  + Launch a single instance of Gimp when opening many files at
    once. (bgo#637234)
  + Fixed folder renaming. (bgo#635417)
  + Fixed search in catalogs not ginving any result. (bgo#638009)
  + Fixed crash on thumbnail generation.
  + Web Albums: update the file info when scaling the original
    image. (bgo#637920)
  + Updated translations.
* Tue Dec 14 2010 vuntz@opensuse.org
- Own /usr/share/gnome and /usr/share/gnome/help to fix build.
* Tue Nov 16 2010 dimstar@opensuse.org
- Update to version 2.12.1:
  + bgo#634615: When moving files do not delete the source if an
    error occurs.
  + bgo#631816: Thumbnails not shown when changing file sorting.
  + bgo#631205: Don't change image on mouse-wheel when editing an
    image.
  + bgo#631997: Respect the PREF_SAVE_THUMBNAILS and
    PREF_THUMBNAIL_LIMIT preference settings.
  + bgo#634050: Fixed crash when a file is renamed.
  + bgo#634052: PicasaWeb importer/exporter: let it work with non
    google email addresses as well.
  + bgo#632498: Facebook uploader: allow to upload to existing
    albums as well.
  + bgo#630836, bgo#630837: Fixed build on BSD systems.
  + Updated translations.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.12.0:
  + Bugs fixed:
  - Do not make catalogs depend on search to fix a circular
    dependency. (bgo#630311)
  - Fixed multi date update when set to 'date photo was taken'.
    (bgo#630016)
  + Updated translations.
* Wed Sep 15 2010 vuntz@opensuse.org
- Update to version 2.11.92:
  + New features and user visible changes:
  - Slideshow: use the same keyword shortcuts used in fullscreen
    mode: space to load the next image; backspace to load the
    previous image; F5 and q to exit the slideshow; p to pause
    the slideshow.
  - Display a pause symbol when the slideshow is paused
    (bgo#627529)
  - Emit a beep when there is no next or previous file.
  - Do not load non-visible thumbnails for web albums to save
    bandwidth.
  + Bugs fixed:
  - Fixed 2.10 catalogs migration.
  - Improved image loading speed by loading the file before
    loading the metadata.
  - Importer: fixed big memory consumption when importing videos.
  - Fixed some loading errors when quickly changing images.
  - Fixed grid not visible in crop tool when using cairo >= 1.9.2
  - Fixed generation of thumbnails when an external script is
    used.
  - Fixed crash when closing the main window and a directory
    loading is underway.
  - Fixed visual glitches when scrolling an image.
  - Fixed crash when changing video in fullscreen mode.
  + Updated translations.
* Mon Aug 30 2010 vuntz@opensuse.org
- Update to version 2.11.91:
  + Remember the inverse sorting option. (bgo#628205)
  + Allow to print a modified image. (bgo#595654)
  + Translate the selection type in the filter editor. (bgo#627532)
  + Allow to create tags with spaces. (bgo#628081)
  + Hide and disable some browser related commands in viewer mode.
    (bgo#627534)
  + Fixed crash when changing the sorting order very fast.
    (bgo#628071)
  + Fixed a crash when resizing many images. (bgo#627688)
  + Fixed crash when saving comments. (bgo#627929)
  + Fixed crash when closing the window. (bgo#627535)
  + Export to PicasaWeb: show an error message if the
    authentication fails; allow to select another account if more
    then one is present. (bgo#627531)
  + Allow to compile with libbrasero 3. (bgo#627646)
  + Fixed the "save only modified fields" option in the comment
    dialog (bgo#627439)
  + Fixed strings marked as translatable but not translated.
    (bgo#627532)
  + Translate the property names in the property view.
  + Fixed the size of the vertical thumbnail pane: make the
    thumbnail pane big enough to avoid to scroll horizontally when
    its orientation is vertical.
  + Fixed image viewer scrolling. (bgo#627466)
  + Fixed saving of IPTC keyworks. Added support for multiple Xpm
    and Iptc metadata with the same key. (bgo#627096)
  + Fixed saving of the 'Other' tab fields in the metadata dialog.
    Specify the type of the fields to allow to create them if they
    are not already present in the image. (bgo#627231)
  + Allow to select non-local folders in the resize and convert
    tools (bgo#627122)
  + More user's manual updates.
  + Updated translations.
* Tue Aug 17 2010 dimstar@opensuse.org
- Update to version 2.11.90:
  + New features and user visible changes:
  - bgo#621244: Slideshow: added ability to view the images in
    random order
  - bgo#622245: Change date tool: allow to set the date without
    touching the time
  - bgo#624454: Video player: display the video speed in the
    status bar and allow to change speed from 0.03 to 36.0
  - Removed the "do not change folder" option from the
    preferences dialog as it was useless.
  - Added ability to organize files by tag
  - bgo#617488: The "fit window to image" is now a toggle action
  - Added two orientation tools: added tool to physically rotate
    the images according to their embedded orientation; and a
    tool to reset the embedded orientation without rotating the
    images.
  - Removed the preferences button from the import dialogs
  - New application icon.
  + Bugs fixed:
  - bgo#626990: Fixed escaping of UTF-chars in ui file
  - bgo#626893: Fixed comment lost when upgrading from 2.10 to
    2.11
  - bgo#625937: Fixed unnecessary reloading when setting a filter
  - bgo#626284: Fixed saving of Xmp and Iptc description and
    title fields
  - bgo#619442: Fixed catalog reordering when the catalog is
    sorted and/or filtered
  - bgo#626686: Fixed crash in fullscreen mode when viewing an
    image after a video.
  - Activate the web album extension by default.
  - Correctly hide and show the mouse pointer in the video player
  - Fixed search test when the "match any" option was active.
  - Flicker importer: fixed crash when the image url is not found
* Sat Aug  7 2010 vuntz@opensuse.org
- Update to version 2.11.6:
  + New features and user visible changes:
  - Added ability to sort by path (bgo#625610)
  - Crop tool: allow to force dimesions as multiple of 8 or other
    sizes (bgo#622385)
  - Convert the old catalogs to the new format and location
    (bgo#618302)
  - Show an information dialog after creating a web album
    (bgo#624264)
  - After setting a desktop background an info-bar is displayd at
    the bottom of the window to allow the user to reset the
    previous background or to open the background preferences.
  + Bugs fixed:
  - bgo#624579, bgo#624932, bgo#623906, bgo#625187, bgo#612809,
    bgo#596906, bgo#624326
  - Preserve the exif data after a lossless rotation
  - Removed use of the gdk_draw_* functions, always use cairo
    instead.
  + Updated translations.
- Changes from version 2.11.5:
  + New features and user visible changes:
  - Added ability to add a tag to the selected files from the
    context menu.
  - Added ability to assign a keyboard shortcut to a script.
  - Added ability to sort by image/video dimensions (bgo#619299)
  - Added ability to search/filter by modified/original date
    (bgo#623159)
  - Added other keyboard shortcuts.
  - Slideshow: added PageDown and PageUp as navigation keys
    (bgo#623599)
  - Added the list of tags to the tag filter control.
  - Automatically select the catalog after creating it.
  - Use the non-clutter projector when no effect is selected.
  - Other updates to the user's manual.
  + Bugs fixed:
  - bgo#623995, bgo#623617, bgo#619491, bgo#623511, bgo#620962,
    bgo#620765, bgo#608115, bgo#623071
  - Fixed crashes.
  - Fixed volume scale in the media player: allow to change the
    volume from 0 to 200%% instead of from 0 to 1000%%
  - Fixed multiple selection with shift + mouse click.
  - Fixed a memory leak in the slideshow.
  - Fixed tiff image corruption when saving the metadata.
  + Updated translations.
- Changes from version 2.11.4:
  + New features and user visible changes:
  - Added a PhotoBucket exporter.
  - Added a static web album creation tool.
  - Allow to edit the metadata of many files at the same time.
  - Use a simple slideshow with no 3D effects if clutter is not
    available.
  - Added option to choose the thumbnail pane orientation.
  - Added drag&drop support to the folder tree. (bgo#593431)
  - In slideshow mode, make button 1 view the next image and
    button 3 the previous image.
  - In the Crop tool added an optional grid. (bgo#618026)
  - Added ability to select the aspect ratio in the Resize tool.
  - Added a share tool menu and the print command on the toolbar.
  - Allow to run gthumb even if clutter initialization fails.
  - Implemented the "confirm deletion" option. (bgo#622386)
  - Avoid duplicates in the history. (bgo#615442)
  - Expand parent after folder creation. (bgo#616940)
  - Save and restore the options of "Rename files" dialog.
    (bgo#618182)
  - Save and restore the options of the Crop and Resize tools.
  - Move "Set as Desktop Background" item from "Tools" menu to
    right-click popup menu. (bgo#618430)
  - Added some aspect ratio in crop tools. (bgo#587787)
  - Do not select the folder after right-clicking on it.
  - Updated the user's manual. Migrated to Mallard.
  + Bugs fixed: bgo#623000, bgo#619758, bgo#619352, bgo#616842,
    bgo#617952, bgo#618183, bgo#618262, bgo#618442, bgo#618554,
    bgo#617282, bgo#616782, bgo#617287, bgo#614219, bgo#611115,
    bgo#616454
  + Updated translations.
- Changes from version 2.11.3:
  + New features and user visible changes:
  - Added an "Export to disc" tool, to burn files to optical
    discs.
  - Added a Flickr importer and exporter.
  - Added a Facebook exporter.
  - Save web account passwords in the GNOME Keyring if available.
  - Added option to avoid to store metadata in files.
    (bgo#533819)
  - Added a thumbnail pane in viewer mode. (bgo#533132)
  - Read the image thumbnail from the embedded metadata if
    available.
  - Organize extensions in categories.
  - Added a fade effect to the slide transition.
  - Make shift-click select a range of consecutive files.
    (bgo#610419)
  - Use delete to move to trash and shift+delete to delete files.
    (bgo#595763)
  - Updated the user manual.
  + Bugs fixed: bgo#615310, bgo#614450, bgo#613875, bgo#612809,
    bgo#603642, bgo#612629, bgo#611812, bgo#478990, bgo#610389,
    bgo#611456, bgo#610873, bgo#611156
  + Updated translations.
* Tue Feb 23 2010 vuntz@opensuse.org
- Update to version 2.11.2.1:
  + Fixed build error. (bgo#610742)
  + Updated translation.
- Add brasero-devel, libgnome-keyring-devel, libsoup-devel
  BuildRequires.
* Tue Feb 23 2010 vuntz@opensuse.org
- Update to version 2.11.2:
  + New features and user visible changes:
  - Added the "convert format" tool, the "change date" tool, the
    "resize image" tool.
  - Added a Picasa Web importer and exporter.
  - Added ability to specify a list of audio files to play during
    a slideshow, and to personalize the slideshow options for
    each catalog.
  - Create the "command line" catalog if more than a file is
    specified at command line.
  - Photo importer: always use the "Last imported" special
    catalog instead of creating a new catalog for each import
    operation; added ability to specify a custom format, the
    custom format consists of the strftime format plus the %%E
    code which is used to specify the event name.
  - Rename files: added %%D and %%M for file dates; allow to
    specify a custom date format; use %%A instead of %%attr for the
    generic attribute.
  - Resize tool changes: added ability to specify a destination
    folder; ask confirmation before overwriting a file. (#605914)
  - Wrap the file captions if they don't fit the available space.
    (#594134)
  - Allow to disable comment synchronization with embedded
    metadata. (#604720)
  - Allow to view an image directly in fullscreen mode
    double-clicking with the middle mouse button.
  - Changed some key accelerators: control+delete to move the
    selected files to the trash; control+shift+delete to delete
    the selected files.
  - Used a preloader to speed-up image loading during a
    slideshow.
  - Added icons to the image tools.
  + Bugs fixed:
  - Fixed double-click that sometimes doesn't open the viewer.
  - Fixed saving of tiff files when there is an alpha channel
    (#610388).
  - Fixed some focus issues (#608364, #608364). Give focus to the
    file list by default (#608364).
  - Do not delete the metadata after rotating or resizing images
    (#610389)
  - Show a warning if no file was imported, or the delete
    operation is not supported (#610190)
  - Fixed not refreshed images after rotation (#610091).
  - Fixed importer failure if the delete operation is not
    supported (#610090)
  - Added missing modules and libraries to LIBADD (#608710)
  - Fixed crash when deleting files (#608717)
  - Make the code compile with the sunstudio compiler (#608660)
  - Fixed crash on mouse wheel move (#608463)
  - Corrected minor spelling and grammar mistakes in the
    documentation (#597353)
  - Added a --disable-deprecated option to configure to disable
    deprecated API usage. (#607757)
  - Use a "command line catalog" if more files are specified on
    the command line (#606203)
  - Fixed crash when loading a file from a location which is not
    the current location. (#606205)
  - Fixed missing extension linking. Some extensions were
    "underlinked". (#606507)
  - Fixed slideshow crash.
  - Do not ignore CFLAGS. (#606227)
  - Use the default data dir instead of hardcoding the gthumb-2.0
    value (#606052)
  - Modernized autotools syntax as suggested by autoupdate.
  - Activated silent rules by default.
  + Updated translations.
- Drop gthumb-no-disable-deprecated.patch: fixed upstream.
* Fri Jan 22 2010 vuntz@opensuse.org
- Add gthumb-no-disable-deprecated.patch to fix build with new
  GTK+: we don't need to ignore deprecated API.
* Tue Jan  5 2010 vuntz@opensuse.org
- Update to version 2.11.1:
  + New features and user visible changes:
  - Added a video/audio player.
  - Allow to edit IPTC/XMP fields.
  - Added 3D effects to the slideshow transition.
  - Use a tree view for the folders.
  - Catalogs are listed in the folder tree instead of using a
    different pane.
  - Allow to create custom file filters. Allow to view any kind
    of file not just images, audio and video files.
  - Allow to search files in the libraries (catalog collections).
  - Added tool to automatically organize files in catalogs, based
    on the file creation or modification date.
  - Allow to choose the metadata to display in the file list.
  - The cut and red-eye removal tools are now integrated in the
    image viewer, instead of using a separate dialog.
  - Added an "Adjust colors" tool to modify the colors of an
    image in single place.
  - Group imported files by date, automatically creating a
    catalog for each different date, furthermore creates a
    catalog with all the imported files.
  - Removed the Tools menu, the file list tools are now listed in
    a toolbar dropdown button.
  - Allow to add files to catalogs using the context submenu,
    instead of using a separate dialog.
  - Use a context submenu to open a file with an external
    application instead of using a separate dialog.
  - Allow to set a custom name for the bookmark menu items.
  - Added a delete command to permanently delete files without
    moving them to the trash.
  - Allow to choose the metadata to print, instead of just
    allowing to print the comment.
  - Moved the system bookmarks in the Bookmarks menu.
  - Allow to set the file type specific options in the
    preferences dialog instead of always asking them before
    saving a file.
  - The image properties are displayed in a sidebar, no more at
    the bottom of the image.
  - Removed the Image menu. Image tools are now listed in a
    sidebar when the image viewer mode is active.
  - Allow to set a title and a date for the catalogs.
  - Searches are updated in place, without the use of a separate
    dialog.
  - Removed the script menu, and moved the scripts in a toolbar
    dropdown button. Simplified the script editor tough it still
    requires some advanced skill to be used.
  - Started work to use modern icons.
  + Technical changes:
  - Rewritten the whole code in order to use an extension (or
    plug-in) based architecture that allows to add new features
    with ease.
  - Removed the use of old and deprecated libraries such as
    gnome-vfs, libgnome, libgnomeui, libgnomecanvas, libbonobo
    and many others.
  + Regressions:
  - Some tools, present in the 2.10 series, are missing because
    of the complete code rewrite. Some of these tools are
    considered important, such as the web album exporter, and
    will be added during the 2.11 development series, other
    secondary tools will added in the next development cycle
    (2.13).
- Changes from version 2.10.12:
  + Bugs fixed:
  - Made the OK button the default widget in the rename dialog.
  - The existing import scripts did not properly unmount
    gvfs-mounted cameras. bgo#560352, lp#351122.
  - Fixed various small memory leaks, bgo#578282.
- Generally clean up packaging.
- Remove unneeded BuildRequires: gcc-c++, hicolor-icon-theme,
  libglade2-devel, libgnomeui-devel, libgphoto2-devel, libidl,
  libiptcdata-devel.
- Add new BuildRequires: clutter-devel, clutter-gtk-devel,
  gconf2-devel, gstreamer-0_10-devel,
  gstreamer-0_10-plugins-base-devel, gtk2-devel, libexiv2-devel,
  libjpeg-devel, libopenraw-devel, libunique-devel
- Use libexecdir instead of prefix/lib.
- Pass --enable-libopenraw to configure.
- Do not create and then remove datadir/application-registry.
- Do not update the name of gthumb.desktop: it's already correct.
- Do not package omf files twice.
- Create a devel subpackage.
* Fri May  1 2009 vuntz@novell.com
- Do not add DocPath to gthumb.desktop: it's not needed for yelp.
- Do not add GNOME, GTK and Photography categories to
  gthumb.desktop since it's already in the desktop file.
- Call suse_update_desktop_file on gthumb-import.desktop.
* Wed Mar 11 2009 mboman@suse.de
- Update to version 2.10.11:
  + bgo#572342: Better IFD offset checking
  + bgo#570473: gthumb write to freed memory
  + bgo#568894: use gtk_widget_get_action (foo), instead of
    g_object_get_data (foo, "gtk-action")
  + bgo#565708: Fixed default launch-with-gimp hotkey to launch
    gimp in the background
  + bgo#563956: Fixed XML comment reading
  + bgo#554240: Provide support for the Mac OS X menubar
  + bgo#560055: filter problems
  + bgo#551225: Modified the build files to better support gtk on
    MAC OS / Quartz
  + bgo#560352: Added a new gthumb-import.desktop.in file to handle
    gvfs-mounted cameras more elegantly. The camera is first
    unmounted, and the libgphoto import routines are then run
  + bgo#557640: Set pagesize adjustment to zero for spinbuttons, to
    avoid annoying warnings
  + bgo#554149: Terminate "Converting comment system...done" with
    newline
  + bgo#555549: The "g" key now launches the "gimp" command,
    instead of the deprecated "gimp-remote" command
  + Fix crasher bug in exif tag reading, caused by malformed tiff
    headers. ld#316017
  + Give the photo-import desktop file different name parameters,
    so that users can distinguish it from the normal desktop file.
    ld#318694
  + Translation updates
- Remove custom CFLAGS
- Remove scrollkeeper from BuildRequires
- Remove Requires hicolor-icon-theme. Should be automatic
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Sat Jan 31 2009 vuntz@novell.com
- Removed unneeded BuildRequires: libgnomeprintui-devel,
  libwnck-devel
- Use sr@latin instead of sr@Latn.
* Wed Oct  1 2008 mboman@suse.de
- Update to version 2.10.10:
  * Added ability to hide video and audio files, using the gconf key
    /apps/gthumb/browser/show_only_images.
  * bgo#552453: gthumb 2.10.9 contains COPYING for GPL v3
  * bgo#546383: gthumb 2.10.9 fails to link
  * Do not exclude xcf images from the file list.
  + Translation updates
* Mon Sep  1 2008 mboman@novell.com
- Update to version 2.10.9:
  + Bugs fixed: bgo#508873, bgo#510326, bgo#510521, bgo#477285,
    bgo#507790, bgo#512374, bgo#543584, bgo#543771, bgo#544893
  + Update translations
- Removed gthumb-gphotofix.patch. Fixed upstream
- Removed gthumb-iptcdata.patch. Not used.
* Fri Jul 18 2008 meissner@suse.de
- fixed build with libgphoto2 2.4.2, see bgo#543584
* Sat Jan  5 2008 bwalle@suse.de
- update to 2.10.8
- removed patches, fixed upstream
* Tue Aug 28 2007 stbinner@suse.de
- fix .desktop file: don't repeat GenericName content within Name
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage.
* Sun Jun 17 2007 ro@suse.de
- avoid string compare with char literal
* Fri Apr 27 2007 sbrabec@suse.cz
- Do not call meinproc (#227624).
- Require hicolor-icon-theme.
* Thu Mar  8 2007 sbrabec@suse.cz
- Removed obsolete hicolor icon symlink (#248676).
- Reduced BuildRequires.
- Enabled TIFF support.
- Spec file cleanup.
* Mon Jan 29 2007 ro@suse.de
- GNOME moved to /usr
* Sun Oct 22 2006 meissner@suse.de
- buildrequirs libgphoto2-devel
* Mon Oct  2 2006 jhargadon@suse.de
- update to version 2.7.9
- Set a smaller height for the progressbar to avoid an image resize.
- Only display user visible drives in the location box.
- many bug fixes.
* Thu Sep 21 2006 jhargadon@suse.de
- update to version 2.7.4
- Fixed bug #325833 – gthumb icon isn't on window title bar and windo
  list applet
- Fixed bug #326844 – Scale Series: Prevent rename .jpg to .jpeg
- Fixed bug #333102 – Image rotation action does not update the EXIF
  tag correctly
-  Fixed bug #331714 - crash in Preferences Browser
- Fixed bug #327245 - Full screen mode crippled if Xinerama is used
- Fixed bug #313827 – Search does not work on categories with colon
  symbol and similar names.
- Fixed bug #331658 - EXIF attributes are not preserved after an image
  modification + save
- Fixed bug #327263 - Save doesn't work, save as does.
- Fixed bug #327262 - Gthumb deletes exif data too aggressively
- Fixed bug #329889 - thumbnail generation and accentuated characters
  in path.
- Fixed bug #329139 - Doesn't determine image type from content anymore
- Improved the crop dialog.
- Fixed bug #329600 – Deleting the Catalogue Search\ Results causes
  erroneous behaviour.
- Fixed bug #328010 - Add GNOME or GTK categories o the .desktop file
- Fixed bug #327049 – Fix build with gcc 2.95
- Fixed bug #325846 - gthumb refuses to compile with libexif-0.6.13.
- Added ability to enable/disable many features in configure.in
- Fixed bug #307959 - "Open With..." dialog offers gthumb as an option.
- Fixed bug #324017 - failed to initialize Canon powerShot G5 due an GTK          bug.
- Fixed bug #325211 - Image quality in web album.
- Fixed bug #325308 - gThumb crash when reaching the end of a directory
  during fullscreen viewing.
- Fixed bug #325507 - gthumb crashes if startup_location gconf pref is
  invalid
* Tue Feb 28 2006 sbrabec@suse.cz
- Use kdelibs3-doc in BuildRequires for meinproc (#153635#c14).
* Thu Feb 23 2006 sbrabec@suse.cz
- Updated Categories, move to Photography (#130232).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 sbrabec@suse.cz
- Updated to version 2.7.2.
* Mon Sep 19 2005 sbrabec@suse.cz
- Fixed Delete All Comments close window (#6286).
* Fri Aug 19 2005 sbrabec@suse.cz
- Added portait web sizes patch.
  http://bugzilla.gnome.org/show_bug.cgi?id=313671
* Thu Jun 30 2005 sbrabec@suse.cz
- Updated to version 2.6.6.
* Fri Jan 28 2005 sbrabec@suse.cz
- Added -fno-strict-aliasing.
* Thu Jan 27 2005 meissner@suse.de
- use NULL as terminator for g_strconcat.
* Tue Jan 25 2005 gekker@suse.de
- Update to version 2.6.3
* Wed Jan 19 2005 ro@suse.de
- added c++ to neededforbuild (for libtiff)
* Mon Nov 22 2004 ro@suse.de
- make specfile rpm3 compliant ...
  (non numeric if arguments need quoting)
- apply exif patch only for > 9.1
* Mon Nov 22 2004 ro@suse.de
- fixed one compiler warning
* Tue Nov  2 2004 ro@suse.de
- locale rename: no -> nb
* Tue Oct 12 2004 sbrabec@suse.cz
- Fixed libexecdir for bi-arch (#47050).
* Sat Sep  4 2004 ro@suse.de
- fix typo in specfile
* Tue Aug 31 2004 clahey@suse.de
- Cache gthumb help and show gthumb in khelpcenter.
* Mon Aug 16 2004 shprasad@suse.de
- Fixes bug #61331  (Fix given by gsunil@novell.com)
  Resets sequence after save.
- Fixes bug #59748  (Fix given by gsunil@novell.com)
  Fixes slide show bug.
- Fixes bug #61594  (Fix given by gsunil@novell.com)
  Fixes search regular expression.
- Fixes bug #62334  (Fix given by gsunil@novell.com)
  Fixes duplicate image after save.
* Fri Jul 30 2004 meissner@suse.de
- Ported to use new libexif api.
* Tue May 11 2004 sbrabec@suse.cz
- Updated to version 2.3.3.
* Wed Mar 17 2004 sbrabec@suse.cz
- Fixed scrollkeeper calling conventions (#36215).
* Wed Mar 10 2004 sbrabec@suse.cz
- Fixed gconf schemas installation (#33114).
- Fixed scrollkeeper installation.
* Tue Mar  2 2004 sbrabec@suse.cz
- Updated to version 2.2.1.
- Enable shared libraries (bug #33881).
* Fri Feb 20 2004 sbrabec@suse.cz
- Fixed PreReq.
* Wed Feb 18 2004 sbrabec@suse.cz
- Updated to version 2.2.0.
* Sat Jan 10 2004 adrian@suse.de
- remove unneeded %%run_ldconfig
* Thu Oct  9 2003 hhetter@suse.de
- updated to version 2.1.6
* Mon Aug 18 2003 sbrabec@suse.cz
- Updated to version 2.1.4.
* Tue Aug 12 2003 adrian@suse.de
- add Viewer Category
* Tue Jul 29 2003 hhetter@suse.de
- %%_lib fixes
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Sat Jun 28 2003 coolo@suse.de
- package directories
- use %%find_lang
* Thu Jun  5 2003 hhetter@suse.de
- fix filelist and schemas
* Wed Feb 26 2003 sbrabec@suse.cz
- FHS fix.
* Wed Feb 26 2003 hhetter@suse.de
- updated to stable 2.0.1 release (#24350)
* Mon Jan 20 2003 ro@suse.de
- update to 1.108
- hack for libgnomeprint(ui) 2.2
* Fri Jan 17 2003 ro@suse.de
- configure: accept libgnomeprint-2.2
* Tue Jan 14 2003 ro@suse.de
- added expat to neededforbuild
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xf86 xdevel> to <x-devel-packages>
* Fri Sep 20 2002 sbrabec@suse.cz
- Added alsa to neededforbuild, because esound can depend on it.
* Tue Aug 13 2002 hhetter@suse.de
- fix filelist for libexec binaries
* Mon Aug 12 2002 hhetter@suse.de
- updated to version 1.103
  * New tool: jpeg lossless transformations.
  * The user can edit/view comments and delete images
  in fullscreen mode.
  * Changed the fourth layout type to something more usefull.
  * Automatically update the content of a folder.
* Sun Aug 11 2002 ro@suse.de
- added openssl, openssl-devel to neededforbuild
* Wed Jul 17 2002 uli@suse.de
- fixed to build on lib64 archs
* Tue Jul 16 2002 jordi@suse.de
- updated to version 1.102
  * New tool: rename series of images.
  * Added a maintenance dialog where the user can delete old/all
    comments/thumbnails, and backup and restore comments.
  * Added header and footer support to the "Index Image" tool.
  * Re-added the "Toolbar Style" option.
  * Added Next/Prev Image buttons on toolbar.
  * Click on an image to view the next one.
  * Minor usability improvements.
* Thu Jul 11 2002 jordi@suse.de
- initial SuSE release
